Module write

Module write 

List all the files we expect to be produced from code with omnidoc attributes.

Structs

DocExtraction
Represents a documentation extraction with its target path and metadata
WriteReport
Report of write operation results

Functions

extract_all_docs
Extracts all documentation from a parsed file
find_expected_doc_paths
Finds all documentation paths that are expected based on code structure
write_extractions
Writes documentation extractions to markdown files