pub fn get_or_create_docs_path(
source_file: &Path,
dry_run: bool,
) -> Result<(String, DocsPathMode), ConfigError>Expand description
Gets or creates the docs-path configuration
Returns a tuple of (path, mode) where mode indicates whether the path is configured via TOML or should be inlined.
If the docs-path is not set in Cargo.toml, this function will append the default configuration and return “docs” (unless dry_run is true).