List all the files we expect to be produced from code with omnidoc attributes.
Structs
- DocExtraction
- Represents a documentation extraction with its target path and metadata
- Write
Report - Report of write operation results
Functions
- extract_
all_ docs - Extracts all documentation from a parsed file
- find_
expected_ doc_ paths - Finds all documentation paths that are expected based on code structure
- write_
extractions - Writes documentation extractions to markdown files